@@ -1,25 +1,28 @@
-# $Id: /mirror/coderepos/lang/perl/Google-Chart/branches/moose/lib/Google/Chart.pm 67454 2008-07-29T23:23:34.150378Z daisuke  $
+# $Id$
 
 package Google::Chart;
+use 5.008;
 use Moose;
 use Google::Chart::Axis;
 use Google::Chart::Legend;
+use Google::Chart::Grid;
 use Google::Chart::Color;
 use Google::Chart::Data;
 use Google::Chart::Size;
 use Google::Chart::Type;
 use Google::Chart::Types;
+use Google::Chart::Title;
+use Google::Chart::Margin;
 use LWP::UserAgent;
 use URI;
 use overload
     '""' => \&as_uri,
     fallback => 1,
 ;
-our $USER_AGENT;
 
 use constant BASE_URI => URI->new("http://chart.apis.google.com/chart");
 
-our $VERSION   = '0.05000';
+our $VERSION   = '0.05014_01';
 our $AUTHORITY = 'cpan:DMAKI';
 
 my %COMPONENTS = (
@@ -44,6 +47,11 @@ my %COMPONENTS = (
         does     => 'Google::Chart::Legend',
         coerce   => 1,
     },
+    grid => {
+        is       => 'rw',
+        isa     => 'Google::Chart::Grid',
+        coerce   => 1,
+    },
     size => {
         is       => 'rw',
         isa      => 'Google::Chart::Size',
@@ -66,7 +74,17 @@ my %COMPONENTS = (
         is       => 'rw',
         does     => 'Google::Chart::Fill',
         coerce   => 1
-    }
+    },
+    title => {
+        is       => 'rw',
+        does     => 'Google::Chart::Title',
+        coerce   => 1
+    },
+    margin => {
+        is       => 'rw',
+        does     => 'Google::Chart::Margin',
+        coerce   => 1
+    },
 );
 my @COMPONENTS = keys %COMPONENTS;
 
@@ -77,17 +95,25 @@ my @COMPONENTS = keys %COMPONENTS;
 }
 
 has 'ua' => (
-    is       => 'rw',
-    isa      => 'LWP::UserAgent',
-    required => 1,
-    lazy     => 1,
-    default  => sub { $USER_AGENT ||= LWP::UserAgent->new() }
+    is         => 'rw',
+    isa        => 'LWP::UserAgent',
+    required   => 1,
+    lazy_build => 1,
 );
 
 __PACKAGE__->meta->make_immutable;
 
 no Moose;
 
+sub _build_ua {
+    my $self = shift;
+    my $ua = LWP::UserAgent->new(
+        agent => "perl/Google-Chart-$VERSION",
+        env_proxy => exists $ENV{GOOGLE_CHART_ENV_PROXY} ? $ENV{GOOGLE_CHART_ENV_PROXY} : 1,
+    );
+    return $ua;
+}
+
 # XXX 
 # We need a trigger function that gets called whenever a component
 # is set, so we can validate if the combination of components are
@@ -128,9 +154,16 @@ sub render {
 }
 
 sub render_to_file {
-    my ($self, $filename) = @_;
+    # XXX - This is done like this because there was a document-implementation
+    # mismatch. In the future, single argument form should be deprecated
+    my $self = shift;
+    my $filename = (@_ > 1) ? do {
+        my %args = @_;
+        $args{filename};
+    }: $_[0];
 
     open my $fh, '>', $filename or die "can't open $filename for writing: $!\n";
+    binmode($fh); # be nice to windows
     print $fh $self->render;
     close $fh or die "can't close $filename: $!\n";
 }
@@ -170,6 +203,8 @@ backwards compatibility.
 
 =head2 new(%args)
 
+Creates a new Google::Chart instance. 
+
 =over 4
 
 =item type
@@ -182,6 +217,14 @@ If you want to pass parameters to the constructor, either pass in an
 already instanstiated object, or pass in a hash, which will be coerced to
 the appropriate object
 
+  my $chart = Google::Chart->new(
+    type => Google::Chart::Bar->new(
+      orientation => "horizontal"
+    )
+  );
+
+  # or
+
   my $chart = Google::Chart->new(
     type => {
       module => "Bar",
@@ -215,6 +258,14 @@ Specifies the markers that go on line charts.
 
 Specifies the axis labels and such that go on line and bar charts
 
+=item legend
+
+=item color
+
+=item fill
+
+=item
+
 =back
 
 =head2 as_uri()
@@ -224,12 +275,24 @@ Returns the URI that represents the chart object.
 =head2 render()
 
 Generates the chart image, and returns the contents.
+This method internally uses LWP::UserAgent. If you want to customize LWP settings, create an instance of LWP::UserAgent and pass it in the constructor
+
+    Google::Chart->new(
+        ....,
+        ua => LWP::UserAgent->new( %your_args )
+    );
+
+Proxy settings are automatically read via LWP::UserAgent->env_proxy(), unless you specify GOOGLE_CHART_ENV_PROXY environment variable to 0
 
 =head2 render_to_file( %args )
 
 Generates the chart, and writes the contents out to the file specified by
 `filename' parameter
 
+=head2 BASE_URI
+
+The base URI for Google Chart
+
 =head1 FEEDBACK
 
 We don't believe that we fully utilize Google Chart's abilities. So there
@@ -246,10 +309,6 @@ code snippets, pseudocode, or even better, test cases, are most welcome.
 Objects need to expect data in a standard format. This is not the case yet.
 (comments welcome)
 
-=item Adding New Components Is Cumbersome
-
-There must be an easy way to just plug it in.
-
 =item Moose-ish Errors
 
 I've been reported that some Moose-related errors occur on certain platforms.
@@ -272,4 +331,5 @@ This program is free software; you can redistribute it and/or modify it
 under the same terms as Perl itself.
 
 See http://www.perl.com/perl/misc/Artistic.html
+
 =cut
