@@ -1,4 +1,4 @@
-# $Id: /mirror/coderepos/lang/perl/Google-Chart/branches/moose/lib/Google/Chart/Fill/LinearGradient.pm 67427 2008-07-29T10:40:51.707813Z lopnor  $
+# $Id$
 
 package Google::Chart::Fill::LinearGradient;
 use Moose;
@@ -33,27 +33,40 @@ has 'angle' => (
     required => 1
 );
 
-has 'color' => (
+has 'color1' => (
     is => 'rw',
     isa => 'Google::Chart::Color::Data',
     required => 1
 );
 
-has 'offset' => (
+has 'color2' => (
+    is => 'rw',
+    isa => 'Google::Chart::Color::Data',
+    required => 1
+);
+
+has 'offset1' => (
     is => 'rw',
     isa => 'Google::Chart::Fill::LinearGradient::Offset',
     default => 0,
     required => 1,
 );
 
+has 'offset2' => (
+    is => 'rw',
+    isa => 'Google::Chart::Fill::LinearGradient::Offset',
+    default => 0,
+    required => 1,
+);
 
 __PACKAGE__->meta->make_immutable;
 
 no Moose;
+no Moose::Util::TypeConstraints;
 
 sub parameter_value {
     my $self = shift;
-    return join(",", $self->target, 'lg', $self->angle, $self->color, $self->offset);
+    return join(",", $self->target, 'lg', $self->angle, $self->color1, $self->offset1, $self->color2, $self->offset2);
 }
 
 1;
