@@ -1,4 +1,4 @@
-# $Id: /mirror/coderepos/lang/perl/Google-Chart/branches/moose/lib/Google/Chart/Fill/Solid.pm 67456 2008-07-29T23:42:23.504022Z daisuke  $
+# $Id$
 
 package Google::Chart::Fill::Solid;
 use Moose;
@@ -22,6 +22,7 @@ has 'target' => (
 __PACKAGE__->meta->make_immutable;
 
 no Moose;
+no Moose::Util::TypeConstraints;
 
 sub parameter_value {
     my $self = shift;
@@ -36,8 +37,23 @@ __END__
 
 Google::Chart::Fill::Solid - Apply Solid Fill
 
-=head1 METHODS
+=head1 SYNOPSIS
 
-=head2 parameter_value
+  use Google::Chart;
+  Google::Chart->new(
+    fill => {
+      args => {
+        color => "ffccff",
+        target => "bg",
+      }
+    }
+  );
+
+  Google::Chart->new(
+    fill => Google::Chart::Fill::Solid->new(
+      color => "ffcff",
+      target => "bg"
+    )
+  );
 
 =cut
