@@ -1,4 +1,4 @@
-# $Id: /mirror/coderepos/lang/perl/Google-Chart/branches/moose/lib/Google/Chart/Legend.pm 67460 2008-07-30T00:04:42.925021Z daisuke  $
+# $Id$
 
 package Google::Chart::Legend;
 use Moose;
@@ -27,22 +27,22 @@ coerce 'Google::Chart::Legend'
     }
 ;
 
-subtype 'Google::Chart::Legend::Value'
+subtype 'Google::Chart::Legend::Data'
     => as 'Str'
 ;
 
-subtype 'Google::Chart::Legend::ValueList'
-    => as 'ArrayRef[Google::Chart::Legend::Value]',
+subtype 'Google::Chart::Legend::DataList'
+    => as 'ArrayRef[Google::Chart::Legend::Data]',
 ;
 
-coerce 'Google::Chart::Legend::ValueList'
+coerce 'Google::Chart::Legend::DataList'
     => from 'Str'
     => via { [ $_ ] }
 ;
 
 has 'values' => (
     is => 'rw',
-    isa => 'Google::Chart::Legend::ValueList',
+    isa => 'Google::Chart::Legend::DataList',
     coerce => 1,
     required => 1,
     default => sub { +[] }
@@ -56,6 +56,7 @@ has 'position' => (
 __PACKAGE__->meta->make_immutable;
 
 no Moose;
+no Moose::Util::TypeConstraints;
 
 sub as_query {
     my $self = shift;
@@ -80,4 +81,8 @@ __END__
 
 Google::Chart::Legend - Google::Chart Legend
 
+=head1 METHODS
+
+=head2 as_query
+
 =cut
