@@ -1,8 +1,16 @@
-# $Id: /mirror/coderepos/lang/perl/Google-Chart/branches/moose/lib/Google/Chart/Title.pm 66700 2008-07-24T09:37:48.241728Z daisuke  $
+# $Id$
 
 package Google::Chart::Title;
 use Moose;
 use Google::Chart::Types;
+use Moose::Util::TypeConstraints;
+
+coerce 'Google::Chart::Title'
+    => from 'HashRef'
+    => via {
+        Google::Chart::Title->new(%$_);
+    }
+;
 
 with 'Google::Chart::QueryComponent';
 
@@ -29,7 +37,7 @@ no Moose;
 sub as_query {
     my $self = shift;
 
-    my $text = $self->title;
+    my $text = $self->text;
     $text =~ s/\r?\n/|/gsm;
     my %data = (
         chtt => $text
@@ -60,4 +68,4 @@ Google::Chart::Title - Apply Title
 
 =head2 as_query
 
-=cut
\ No newline at end of file
+=cut
