@@ -1,4 +1,4 @@
-# $Id: /mirror/coderepos/lang/perl/Google-Chart/branches/moose/lib/Google/Chart/Type/Bar.pm 66683 2008-07-24T05:52:58.814530Z daisuke  $
+# $Id$
 
 package Google::Chart::Type::Bar;
 use Moose;
@@ -8,11 +8,11 @@ with 'Google::Chart::Type::Simple';
 
 enum 'Google::Chart::Type::Bar::Orientation' => qw(horizontal vertical);
 
-has 'colored' => (
+has 'stacked' => (
     is => 'rw',
     isa => 'Bool',
     required => 1,
-    default => 0,
+    default => 1,
 );
 
 has 'orientation' => (
@@ -25,13 +25,14 @@ has 'orientation' => (
 __PACKAGE__->meta->make_immutable;
 
 no Moose;
+no Moose::Util::TypeConstraints;
 
 sub parameter_value {
     my $self = shift;
 
     return sprintf( 'b%s%s', 
         $self->orientation eq 'vertical' ? 'v' : 'h',
-        $self->colored                   ? 'g' : 's'
+        $self->stacked                   ? 's' : 'g'
     );
 }
 
