@@ -1,7 +1,9 @@
-# $Id: /mirror/coderepos/lang/perl/Google-Chart/branches/moose/lib/Google/Chart/Types.pm 67427 2008-07-29T10:40:51.707813Z lopnor  $
+# $Id$
 
 package Google::Chart::Types;
-use Moose;
+use strict;
+use warnings;
+use Carp ();
 use Moose::Util::TypeConstraints;
 use Sub::Exporter -setup => {
     exports => [ qw(hash_coercion) ]
@@ -16,7 +18,7 @@ sub hash_coercion {
     return sub {
         my $h = $_;
         my $module = $h->{module} || $default ||
-            confess "No module name provided for coercion";
+            Carp::confess("No module name provided for coercion");
         if ($module !~ s/^\+//) {
             $module = join('::', $prefix, $module);
         }
@@ -83,7 +85,7 @@ sub hash_coercion {
     ;
 }
 
-no Moose;
+no Moose::Util::TypeConstraints;
 
 1;
 
